@@ -49,7 +49,80 @@ class ContactDetails(BaseModel):
     role: str | None = None
 
 
-class VacancyData(BaseModel):
+class QuestionConfig(BaseModel):
+    id: Optional[UUID] = None
+    created_at: Optional[datetime] = None
+    updated_at: Optional[datetime] = None
+    organization: Optional[UUID] = None
+
+    application_flow_id: Optional[UUID] = None
+    question_category: QuestionCategory
+    key: str
+    question: Optional[str] = None
+    text: Optional[str] = None
+    type: str
+    required: bool
+    options: Optional[list] = []
+
+    @classmethod
+    async def from_model(cls: "QuestionConfig", model: QuestionModel) -> "QuestionConfig":
+        return cls(**model.model_dump())
+
+
+class ApplicationFlowConfig(BaseModel):
+    id: Optional[UUID] = None
+    created_at: Optional[datetime] = None
+    updated_at: Optional[datetime] = None
+    organization: Optional[UUID] = None
+
+    name: str
+    type: ApplicationFlowType
+    questions: list[QuestionConfig]
+
+    @staticmethod
+    async def resolve_object(object_id: UUID, organization_id: UUID) -> "ApplicationFlowConfig | None":
+        result = await MSClient.vacancies().get(f"application-flows/{object_id}", headers={"X-Organization-ID": str(organization_id)})
+
+        if result.status_code != 200:
+            return None
+
+        return ApplicationFlowConfig(**result.json())
+
+    @classmethod
+    async def from_model(cls: "ApplicationFlowConfig", model: ApplicationFlowModel, questions: list[QuestionModel]) -> "ApplicationFlowConfig":
+        return cls(
+            id=model.id,
+            created_at=model.created_at,
+            updated_at=model.updated_at,
+            organization=model.organization,
+            name=model.name,
+            type=model.type,
+            questions=questions,
+        )
+
+
+class ApplicationFlowInfo(BaseModel):
+    id: UUID
+    created_at: datetime
+    updated_at: Optional[datetime]
+    organization: UUID
+
+    name: str
+    type: ApplicationFlowType
+    question_count: int
+    is_used_in_campaign: bool
+    handled_candidates_count: int
+
+    @classmethod
+    async def from_model(cls: "ApplicationFlowInfo", model: ApplicationFlowModel) -> "ApplicationFlowInfo":
+        return cls(
+            **model.model_dump(),
+            question_count=len(model.questions),
+            is_used_in_campaign=False
+        )
+
+
+class RawVacancy(BaseModel):
 
     # Required fields
     reference_number: str
@@ -121,15 +194,30 @@ class VacancyData(BaseModel):
         return model
 
 
-class Vacancy(VacancyData):
+class VacancyConfig(RawVacancy):
     id: UUID
     created_at: datetime
     updated_at: Optional[datetime]
     organization: UUID
+
     feed_id: UUID
+    application_flow_id: Optional[UUID]
+
+
+class VacancyInfo(RawVacancy):
+    id: UUID
+    created_at: datetime
+    updated_at: Optional[datetime]
+    organization: UUID
+
+    feed: "FeedInfo"
+    application_flow: Optional["ApplicationFlowConfig"]
 
     @classmethod
     async def from_model(cls: "Vacancy", model: VacancyModel) -> "Vacancy":
+        feed = await FeedInfo.resolve_object(model.feed_id, model.organization)
+        application_flow = (await ApplicationFlowConfig.from_model(model.application_flow)) if model.application_flow_id else None,
+
         hours = Hours(
             min=model.hours_min,
             max=model.hours_max,
@@ -164,11 +252,13 @@ class Vacancy(VacancyData):
         remote_type = to_enum(RemoteType, getattr(model, "remote_type", None))
 
         return cls(
-            organization=model.organization,
             id=model.id,
             created_at=model.created_at,
             updated_at=model.updated_at,
-            feed_id=model.feed_id,
+            organization=model.organization,
+
+            feed=feed,
+            application_flow=application_flow,
 
             reference_number=model.reference_number,
             requisition_id=model.requisition_id,
@@ -282,70 +372,10 @@ class FeedConfig(BaseModel):
     ats_link_id: Optional[UUID]
     last_sync_date: Optional[datetime]
     synced_vacancy_count: int
+    sanitation_options: Optional[dict]
     mapping: List[Mapping]
     custom_fields: List[Mapping]
 
     @classmethod
     async def from_model(cls: "FeedConfig", model: FeedModel) -> "FeedConfig":
         return cls(**model.model_dump())
-
-
-class QuestionConfig(BaseModel):
-    id: Optional[UUID] = None
-    created_at: Optional[datetime] = None
-    updated_at: Optional[datetime] = None
-    organization: Optional[UUID] = None
-
-    application_flow_id: Optional[UUID] = None
-    question_category: QuestionCategory
-    key: str
-    question: Optional[str] = None
-    text: Optional[str] = None
-    type: str
-    required: bool
-    options: Optional[list] = []
-
-    @classmethod
-    async def from_model(cls: "QuestionConfig", model: QuestionModel) -> "QuestionConfig":
-        return cls(**model.model_dump())
-
-
-class ApplicationFlowConfig(BaseModel):
-    id: Optional[UUID] = None
-    created_at: Optional[datetime] = None
-    updated_at: Optional[datetime] = None
-    organization: Optional[UUID] = None
-
-    name: str
-    type: ApplicationFlowType
-    questions: list[QuestionConfig]
-
-    @classmethod
-    async def from_model(cls: "ApplicationFlowConfig", model: ApplicationFlowModel, questions: list[QuestionModel]) -> "ApplicationFlowConfig":
-        return cls(
-            id=model.id,
-            created_at=model.created_at,
-            updated_at=model.updated_at,
-            organization=model.organization,
-            name=model.name,
-            type=model.type,
-            questions=questions
-        )
-
-
-class ApplicationFlowInfo(BaseModel):
-    id: UUID
-    created_at: datetime
-    updated_at: Optional[datetime]
-    organization: UUID
-
-    name: str
-    type: ApplicationFlowType
-    question_count: int
-
-    @classmethod
-    async def from_model(cls: "ApplicationFlowInfo", model: ApplicationFlowModel) -> "ApplicationFlowInfo":
-        return cls(
-            **model.model_dump(),
-            question_count=len(model.questions)
-        )
\ No newline at end of file
